<script id="ftw-mobile-list-template" type="text/x-handlebars-template">

    <ul class="mobile-menu mobile-menu-{{name}}">
        {{#each items}}

            <li><a href="{{url}}">{{label}}</a></li>

         {{/each}}

    </ul>

</script>
