#portal-personaltools-wrapper {
  display: none;
  @include screen-medium {
    display: block;
  }
}

.navigation, #portal-breadcrumbs {
  @include screen-large() {
    display: block;
  }

  display: none;
}

#portal-logo {
  @include screen-large {
    display: inline-block;
  }

  display: none;

}
